==> jc-1.4.0.tar.gz: polyglot/ext/jl/ast/ArrayAccessAssign__5fc.h <==
// public class polyglot.ext.jl.ast.ArrayAccessAssign_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 38a96ebec5df06d5 polyglot_ext_jl_ast_ArrayAccessAssign__5fc
// @dep_class 953cb1edb05abd0 polyglot_ext_jl_ast_Assign__5fc
// @dep_class 84a81e50f3b403c9 polyglot_ext_jl_ast_Expr__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd12e62b850e429 polyglot_ext_jl_ast_Term__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Assign__5fc

#include "polyglot/ext/jl/ast/Assign__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_ArrayAccessAssign__5fc_H_
#define _JC_polyglot_ext_jl_ast_ArrayAccessAssign__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_ArrayAccess$object;
struct _jc_polyglot_ast_Assign$object;
struct _jc_polyglot_ast_Assign__24Operator$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_CFGBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$_init$d35b1130b39563a3(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, struct _jc_polyglot_ast_Assign__24Operator$object *, struct _jc_object *);

// Virtual methods
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$acceptCFGAssign$8380dedc2116daf6(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *);
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$acceptCFGOpAssign$806af46210cadb1b(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *);
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$assertLeftType$40aa68eb32480226(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$entry$617ff8f143060243(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$left$62370db11e65aefa(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *);
extern struct _jc_object *_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$throwTypes$7c1f300c448e8fc3(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *);
extern jboolean _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$throwsArrayStoreException$ada18b2a97e51a72(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$acceptCFGAssign$8380dedc2116daf6;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$acceptCFGOpAssign$806af46210cadb1b;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$assertLeftType$40aa68eb32480226;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$entry$617ff8f143060243;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$left$62370db11e65aefa;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$throwTypes$7c1f300c448e8fc3;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$throwsArrayStoreException$ada18b2a97e51a72;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods {
	void	(*acceptCFGAssign$8380dedc2116daf6)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *);
	void	(*acceptCFGOpAssign$806af46210cadb1b)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *);
	void	(*assertLeftType$40aa68eb32480226)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *);
	struct _jc_object	*(*entry$617ff8f143060243)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *);
	struct _jc_object	*(*left$62370db11e65aefa)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *);
	struct _jc_object	*(*throwTypes$7c1f300c448e8fc3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *);
	jboolean	(*throwsArrayStoreException$ada18b2a97e51a72)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods	polyglot_ext_jl_ast_Term__5fc;
	_jc_polyglot_ext_jl_ast_Expr__5fc$vmethods	polyglot_ext_jl_ast_Expr__5fc;
	_jc_polyglot_ext_jl_ast_Assign__5fc$vmethods	polyglot_ext_jl_ast_Assign__5fc;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods	polyglot_ext_jl_ast_ArrayAccessAssign__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs {
    _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs	polyglot_ext_jl_ast_ArrayAccessAssign__5fc;
    _jc_polyglot_ext_jl_ast_Assign__5fc$sub_refs	polyglot_ext_jl_ast_Assign__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_refs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_nonrefs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Assign__5fc$sub_nonrefs	polyglot_ext_jl_ast_Assign__5fc;
    _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs	polyglot_ext_jl_ast_ArrayAccessAssign__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object {
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_ArrayAccessAssign__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_ArrayAccessAssign__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/ast/ArrayAccessAssign__5fc.h <==
// public class polyglot.ext.jl.ast.ArrayAccessAssign_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 38a96ebec5df06d5 polyglot_ext_jl_ast_ArrayAccessAssign__5fc
// @dep_class 953cb1edb05abd0 polyglot_ext_jl_ast_Assign__5fc
// @dep_class 84a81e50f3b403c9 polyglot_ext_jl_ast_Expr__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd12e62b850e429 polyglot_ext_jl_ast_Term__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_Assign__5fc

#include "polyglot/ext/jl/ast/Assign__5fc.h"

#ifndef _JC_polyglot_ext_jl_ast_ArrayAccessAssign__5fc_H_
#define _JC_polyglot_ext_jl_ast_ArrayAccessAssign__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_polyglot_ast_ArrayAccess$object;
struct _jc_polyglot_ast_Assign$object;
struct _jc_polyglot_ast_Assign__24Operator$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_Term$object;
struct _jc_polyglot_types_TypeSystem$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_CFGBuilder$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object;

typedef const struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$_init$d35b1130b39563a3(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_object *, struct _jc_polyglot_ast_Assign__24Operator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$acceptCFGAssign$8380dedc2116daf6(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$acceptCFGOpAssign$806af46210cadb1b(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$assertLeftType$40aa68eb32480226(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$entry$617ff8f143060243(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$left$62370db11e65aefa(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$throwTypes$7c1f300c448e8fc3(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method$throwsArrayStoreException$ada18b2a97e51a72(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$acceptCFGAssign$8380dedc2116daf6;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$acceptCFGOpAssign$806af46210cadb1b;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$assertLeftType$40aa68eb32480226;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$entry$617ff8f143060243;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$left$62370db11e65aefa;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$throwTypes$7c1f300c448e8fc3;
extern _jc_method _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$method_info$throwsArrayStoreException$ada18b2a97e51a72;

// Virtual methods structure
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods {
	void	(*acceptCFGAssign$8380dedc2116daf6)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *) _JC_JCNI_ATTR;
	void	(*acceptCFGOpAssign$806af46210cadb1b)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_polyglot_visit_CFGBuilder$object *) _JC_JCNI_ATTR;
	void	(*assertLeftType$40aa68eb32480226)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*entry$617ff8f143060243)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*left$62370db11e65aefa)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*throwTypes$7c1f300c448e8fc3)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*throwsArrayStoreException$ada18b2a97e51a72)(_jc_env *, struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_Term__5fc$vmethods	polyglot_ext_jl_ast_Term__5fc;
	_jc_polyglot_ext_jl_ast_Expr__5fc$vmethods	polyglot_ext_jl_ast_Expr__5fc;
	_jc_polyglot_ext_jl_ast_Assign__5fc$vmethods	polyglot_ext_jl_ast_Assign__5fc;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vmethods	polyglot_ext_jl_ast_ArrayAccessAssign__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs {
    _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_refs	polyglot_ext_jl_ast_ArrayAccessAssign__5fc;
    _jc_polyglot_ext_jl_ast_Assign__5fc$sub_refs	polyglot_ext_jl_ast_Assign__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_refs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_refs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_Term__5fc$sub_nonrefs	polyglot_ext_jl_ast_Term__5fc;
    _jc_polyglot_ext_jl_ast_Expr__5fc$sub_nonrefs	polyglot_ext_jl_ast_Expr__5fc;
    _jc_polyglot_ext_jl_ast_Assign__5fc$sub_nonrefs	polyglot_ext_jl_ast_Assign__5fc;
    _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$sub_nonrefs	polyglot_ext_jl_ast_ArrayAccessAssign__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$object {
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$vtype _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_ast_ArrayAccessAssign__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_ast_ArrayAccessAssign__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_ast_ArrayAccessAssign__5fc_H_ */
